chrome.extension.onRequest.addListener(function(request, sender, sendResponse) {
  if (request.command != "filters_updated")
    return;
  if ($("#txtFiltersAdvanced").prop("disabled") === false)
    return;
  BGcall("get_custom_filters_text", function(text) {
    $("#txtFiltersAdvanced").val(text);
  });
  // a call to sendResponse is not needed because of the call in filters.js
});

$(function() {
    //try to get filter syntax page with users language
    //if it fails, default to english (en).
    var syntaxURL = "https://adblockplus.org/" +
                    determineUserLanguage() +
                    "/filters";

    var jqxhr = $.ajax({
      type: 'get',
      url: syntaxURL,
      success: function(e) {
        //since the ABP site uses a custom server side 404 handler, instead of returing us a 404 http status code
        //we need to parse the response text looking for a 404 message for the user.
        if (jqxhr.responseText &&
            jqxhr.responseText.indexOf("404 - The requested URL was not found.") > 0) {
            $('#tutorlink').attr("href", "https://adblockplus.org/en/filters");
        } else {
            $('#tutorlink').attr("href", syntaxURL);
        }
      },
      error: function(e) {
        $('#tutorlink').attr("href", "https://adblockplus.org/en/filters");
      },
    });


  // Add a custom filter to the list
  function appendCustomFilter(filter) {
    var customFilterText = $("#txtFiltersAdvanced").val();
    $("#txtFiltersAdvanced").val(filter + "\n" + customFilterText);
    saveFilters();
    $(".addControls").slideUp();
  }

  $("#divUrlBlock input[type='text']").bind("input", function() {
    var blockUrl = $("#txtBlockUrl").val().trim();
    var blockDomain = $("#txtBlockUrlDomain").val().trim();
    if (blockDomain == '*')
      blockDomain = '';
    if (blockDomain)
      blockDomain = '$domain=' + blockDomain;
    var ok = false;
    try {
      if (FilterNormalizer.normalizeLine(blockUrl + blockDomain))
        ok = true;
      if (Filter.isSelectorFilter(blockUrl))
        ok = false;
    } catch(ex) {}
    $("#btnAddUrlBlock").prop("disabled", ok ? null : true);
  });

  $("#divCssBlock input[type='text']").bind("input", function() {
    var blockCss = $("#txtUserFilterCss").val().trim();
    var blockDomain = $("#txtUserFilterDomain").val().trim();
    if (blockDomain == '*')
      blockDomain = '';
    var ok = false;
    try {
      if (FilterNormalizer.normalizeLine(blockDomain + "##" + blockCss))
        ok = true;
    } catch(ex) {}
    $("#btnAddUserFilter").prop("disabled", ok ? null : true);
  });

  // When one presses 'Enter', pretend it was a click on the 'add' button
  $(".entryTable input[type='text']").keypress(function(event) {
    var submitButton = $(this).closest(".entryTable").find("input[type='button']");
    if (event.keyCode === 13 && !submitButton.prop("disabled")) {
      event.preventDefault();
      submitButton.click();
    }
  });

  $("a.controlsLink").click(function() {
    event.preventDefault();
    var myControls = $(this).closest("div").find(".addControls");
    $(".addControls").not(myControls).slideUp();
    myControls.slideToggle();
  });

  $("#btnEditAdvancedFilters").click(function() {
    $("#divAddNewFilter").slideUp();
    $(".addControls").slideUp();
    $("#txtFiltersAdvanced").prop("disabled", false);
    $("#spanSaveButton").show();
    $("#btnEditAdvancedFilters").hide();
    $("#txtFiltersAdvanced").focus();
  });

  // Update custom filter count in the background.
  // Inputs: custom_filters_text:string - string representation of the custom filters
  // delimited by new line.
  function updateCustomFiltersCount(custom_filters_text) {
    var custom_filters_array = custom_filters_text.split("\n");
    var new_count = {};
    var temp_filter_tracker = [];
    for(var i = 0; i < custom_filters_array.length; i++) {
      var filter = custom_filters_array[i];
      //Check if filter is a duplicate and that it is a hiding filter.
      if(temp_filter_tracker.indexOf(filter) < 0 && filter.indexOf("##") > -1) {
        temp_filter_tracker.push(filter);
        var host = filter.split("##")[0];
        new_count[host] = (new_count[host] || 0) + 1;
      }
    }
    BGcall("updateCustomFilterCountMap", new_count);
  }

  function saveFilters() {
    var custom_filters_text = $("#txtFiltersAdvanced").val();
    var custom_filters_array = custom_filters_text.split("\n");
    var filterErrorMessage = "";
    $("#messagecustom").html(filterErrorMessage);
    $("#messagecustom").hide();
    for(var i = 0; (!filterErrorMessage && i < custom_filters_array.length); i++) {
      var filter = custom_filters_array[i];
      try {
        FilterNormalizer.normalizeLine(filter);
      } catch(ex) {
        filterErrorMessage = translate("customfilterserrormessage", [filter, ex.message]);
      }
    }
    if (!filterErrorMessage) {
      BGcall("set_custom_filters_text", custom_filters_text);
      updateCustomFiltersCount(custom_filters_text);
      $("#divAddNewFilter").slideDown();
      $("#txtFiltersAdvanced").prop("disabled", true);
      $("#spanSaveButton").hide();
      $("#btnEditAdvancedFilters").show();
      $("#btnCleanUp").show();
    } else {
      $("#messagecustom").html(filterErrorMessage);
      $("#messagecustom").show();
    }
  }

  $("#btnSaveAdvancedFilters").click(saveFilters);

  BGcall("get_custom_filters_text", function(text) {
    $("#txtFiltersAdvanced").val(text);
  });

  $("#btnCleanUp").click(function() {
    //Don't save immediately, first allow them to review changes
    if ($("#btnEditAdvancedFilters").is(":visible"))
      $("#btnEditAdvancedFilters").click();
    var newFilters = FilterNormalizer.normalizeList($("#txtFiltersAdvanced").val(), true);
    newFilters = newFilters.replace(/(\n)+$/,'\n'); // Del trailing \n's
    $("#txtFiltersAdvanced").val(newFilters);
  });
});
